==> easy_ads-1.3.2.tar.gz: lib/interstitial_ad/easy_interstital_ad.dart <==
import 'package:firebase_admob/firebase_admob.dart';

import '../easy_ads.dart';

class EasyInterstitialAd {
  /// ```
  /// Android: 'ca-app-pub-3940256099942544/1033173712'
  ///
  /// IOS: 'ca-app-pub-3940256099942544/4411468910'
  /// ```
  static final String testAdUnitId = InterstitialAd.testAdUnitId;

  InterstitialAd _interstitialAd;

  MobileAdListener _listener;

  /// If not given as an Argument, then EasyAds.defaultTargetingInfo will be used
  MobileAdTargetingInfo targetingInfo;

  /// By default the EasyInterstitialAd.testAdUnitId is used.
  String adUnitID;

  /// ## Description
  ///
  /// * Fuction for the default Listener, on the AdLoaded event.
  ///
  /// ## Parameters
  ///
  /// * none
  AdLoadedFunction onAdLoaded;

  /// Amount of times the MobileAdEvent.loaded triggered
  int _loadedCount;

  /// ## Description
  ///
  /// * Fuction for the default Listener, on the AdClicked event.
  ///
  /// ## Parameters
  ///
  /// * none
  AdClickedFunction onAdClicked;

  /// Amount of times the MobileAdEvent.loaded triggered
  int _clickedCount;

  /// ## Description
  ///
  /// * Fuction for the default Listener, on the AdOpened event.
  ///
  /// ## Parameters
  ///
  /// * none
  AdOpenedFunction onAdOpened;

  /// Amount of times the MobileAdEvent.opened triggered
  int _openedCount;

  /// ## Description
  ///
  /// * Fuction for the default Listener, on the AdImpression event.
  ///
  /// ## Parameters
  ///
  /// * none
  AdStartedFunction onAdImpression;

  /// Amount of times the MobileAdEvent.impression triggered
  int _impressionCount;

  /// ## Description
  ///
  /// * Fuction for the default Listener, on the AdClosed event.
  ///
  /// ## Parameters
  ///
  /// * none
  AdClosedFunction onAdClosed;

  /// Amount of times the MobileAdEvent.closed triggered,
  int _closedCount;

  /// ## Description
  ///
  /// * Fuction for the default Listener, on the LeftApplication event.
  ///
  /// ## Parameters
  ///
  /// * none
  AdLeftApplicationFunction onLeftApplication;

  /// Amount of times the MobileAdEvent.leftApplication triggered
  int _leftApplicationCount;

  /// ## Description
  ///
  /// * Fuction for the default Listener, on the AdFailedToLoad event.
  ///
  /// ## Parameters
  ///
  /// * none
  AdFailedToLoadFunction onAdFailedToLoad;

  /// Amount of times the MobileAdEvent.failedToLoad triggered
  int _failedToLoadCount;

  /// ## Description
  ///
  /// * Fuction for the default Listener, on every event.
  ///
  /// ## Parameters
  ///
  /// * String event
  MobileAdEventTriggeredFunction onAdEvent;

  /// ## Description
  ///
  /// * You `have to` call [EasyAds.initialize], otherwise this class will not work.
  ///
  ///
  /// * The [load] method is called in the constructor.
  ///
  /// ## Example
  ///
  /// {@tool sample}
  /// ```
  /// class MyAdWidget extends StatefulWidget {
  ///   @override
  ///   _MyAdWidgetState createState() => _MyAdWidgetState();
  /// }
  ///
  /// class _MyAdWidgetState extends State<MyAdWidget> {
  ///   EasyInterstitialAd myTestAd;
  ///
  ///   @override
  ///   void initState() {
  ///     super.initState();
  ///     myTestAd = EasyInterstitialAd();
  ///   }
  ///
  ///   @override
  ///   Widget build(BuildContext context) {
  ///     return Scaffold(
  ///       body: Container(
  ///         child: Center(
  ///           child: RaisedButton(onPressed: myTestAd.show),
  ///         ),
  ///       ),
  ///     );
  ///   }
  /// }
  ///
  /// ```
  /// {@end-tool}
  EasyInterstitialAd({
    this.adUnitID,
    this.targetingInfo,
  }) {
    _initAdListener();
    _initValues();

    _interstitialAd = InterstitialAd(
      adUnitId: adUnitID,
      targetingInfo: targetingInfo,
      listener: _listener,
    );

    load();
  }

  void _initValues() {
    adUnitID = adUnitID ?? EasyInterstitialAd.testAdUnitId;
    targetingInfo = targetingInfo ?? EasyAds.defaultTargetingInfo;

    _loadedCount = 0;
    _openedCount = 0;
    _impressionCount = 0;
    _closedCount = 0;
    _leftApplicationCount = 0;
    _failedToLoadCount = 0;
  }

  void _initAdListener() {
    _listener = (MobileAdEvent event) {
      switch (event) {
        case MobileAdEvent.loaded:
          _loadedCount++;
          if (onAdLoaded != null) onAdLoaded();
          break;

        case MobileAdEvent.clicked:
          _clickedCount++;
          if (onAdClicked != null) onAdClicked();
          break;

        case MobileAdEvent.opened:
          _openedCount++;
          if (onAdOpened != null) onAdOpened();
          break;

        case MobileAdEvent.closed:
          _closedCount++;
          if (onAdClosed != null) onAdClosed();
          break;

        case MobileAdEvent.impression:
          _impressionCount++;
          if (onAdImpression != null) onAdImpression();
          break;

        case MobileAdEvent.leftApplication:
          _leftApplicationCount++;
          if (onLeftApplication != null) onLeftApplication();
          break;

        case MobileAdEvent.failedToLoad:
          _failedToLoadCount++;
          if (onAdFailedToLoad != null) onAdFailedToLoad();
          break;
        default:
          if (onAdEvent != null) onAdEvent(event);
      }
    };
  }

  Future<bool> load() => _interstitialAd.load();

  Future<bool> isLoaded() => _interstitialAd.isLoaded();

  /// ## Description
  ///
  /// * The ad must have been loaded with `load` first.
  ///   If loading hasn't finished the ad will not actually
  ///   appear until the ad has finished loading.
  ///
  ///
  /// * The event specific method will get called when the ad has finished
  ///   loading or fails to do so e.g.:
  ///   ```
  ///   MobileAdEvent.loaded => onAdLoaded()
  ///   ```
  ///
  ///
  /// * `anchorOffset` is the logical pixel offset from the edge
  ///   of the screen (default 0.0). `anchorType` place advert at
  ///   top or bottom of screen (default bottom).
  Future<bool> show({
    double anchorOffset = 0.0,
    double horizontalCenterOffset = 0.0,
    AnchorType anchorType = AnchorType.bottom,
  }) =>
      _interstitialAd.show(
          anchorOffset: anchorOffset,
          horizontalCenterOffset: horizontalCenterOffset,
          anchorType: anchorType);

  /// ## Description
  ///
  /// * Put this in `dispose` or `deactivate`, if you are using
  ///   a Stateful Widget
  ///
  ///
  /// * Free the plugin resources associated with this ad.
  ///
  ///
  /// * Disposing a banner ad that's been shown removes it from the screen.
  ///   Interstitial ads can't be programmatically removed from view.
  Future<bool> dispose() => _interstitialAd.dispose();

  /// Get the InterstitialAd instance from the `firebase_admob` library
  InterstitialAd get interstitialAd => _interstitialAd;

  ///returns:
  ///```
  ///Ad_Type.INTERSTITIAL
  ///```
  Ad_Type get adType => Ad_Type.INTERSTITIAL;

  /// * Amount of times the MobileAdEvent.loaded triggered.
  ///
  ///
  /// * Before `onAdLoaded` is called `loadedCount` gets executed.
  ///
  ///
  /// * This value will not be saved in any form.
  int get loadedCount => _loadedCount;

  /// * Amount of times the MobileAdEvent.clicked triggered.
  ///
  ///
  /// * Before `onAdClicked` is called `clickedCount` gets executed.
  ///
  ///
  /// * This value will not be saved in any form.
  int get clickedCount => _clickedCount;

  /// * Amount of times the MobileAdEvent.opened triggered.
  ///
  ///
  /// * Before `onAdOpened` is called `openedCount` gets executed.
  ///
  ///
  /// * This value will not be saved in any form.
  int get openedCount => _openedCount;

  /// * Amount of times the MobileAdEvent.impression triggered.
  ///
  ///
  /// * Before `onAdImpression` is called `impressionCount` gets executed.
  ///
  ///
  /// * This value will not be saved in any form.
  int get impressionCount => _impressionCount;

  /// * Amount of times the MobileAdEvent.closed triggered.
  ///
  ///
  /// * Before `onAdClosed` is called `closedCount` gets executed.
  ///
  ///
  /// * This value will not be saved in any form.
  int get closedCount => _closedCount;

  /// * Amount of times the MobileAdEvent.leftApplication triggered.
  ///
  ///
  /// * Before `onLeftApplication` is called `leftApplicationCount` gets executed.
  ///
  ///
  /// * This value will not be saved in any form.
  int get leftApplicationCount => _leftApplicationCount;

  /// * Amount of times the MobileAdEvent.failedToLoad triggered.
  ///
  ///
  /// * Before `onAdFailedToLoad` is called `failedToLoadCount` gets executed.
  ///
  ///
  /// * This value will not be saved in any form.
  int get failedToLoadCount => _failedToLoadCount;
}

==> easy_ads-2.0.0.tar.gz: lib/interstitial_ad/easy_interstital_ad.dart <==
import 'package:firebase_admob/firebase_admob.dart';

import '../easy_ads.dart';

class EasyInterstitialAd {
  /// ```
  /// Android: 'ca-app-pub-3940256099942544/1033173712'
  ///
  /// IOS: 'ca-app-pub-3940256099942544/4411468910'
  /// ```
  static final String testAdUnitId = InterstitialAd.testAdUnitId;

  InterstitialAd _interstitialAd;

  MobileAdListener _listener;

  /// If not given as an Argument, then EasyAds.defaultTargetingInfo will be used
  MobileAdTargetingInfo targetingInfo;

  /// By default the EasyInterstitialAd.testAdUnitId is used.
  String adUnitId;

  /// ## Description
  ///
  /// * Fuction for the default Listener, on the AdLoaded event.
  ///
  /// ## Parameters
  ///
  /// * none
  AdLoadedFunction onAdLoaded;

  /// Amount of times the MobileAdEvent.loaded triggered
  int _loadedCount;

  /// ## Description
  ///
  /// * Fuction for the default Listener, on the AdClicked event.
  ///
  /// ## Parameters
  ///
  /// * none
  AdClickedFunction onAdClicked;

  /// Amount of times the MobileAdEvent.loaded triggered
  int _clickedCount;

  /// ## Description
  ///
  /// * Fuction for the default Listener, on the AdOpened event.
  ///
  /// ## Parameters
  ///
  /// * none
  AdOpenedFunction onAdOpened;

  /// Amount of times the MobileAdEvent.opened triggered
  int _openedCount;

  /// ## Description
  ///
  /// * Fuction for the default Listener, on the AdImpression event.
  ///
  /// ## Parameters
  ///
  /// * none
  AdStartedFunction onAdImpression;

  /// Amount of times the MobileAdEvent.impression triggered
  int _impressionCount;

  /// ## Description
  ///
  /// * Fuction for the default Listener, on the AdClosed event.
  ///
  /// ## Parameters
  ///
  /// * none
  AdClosedFunction onAdClosed;

  /// Amount of times the MobileAdEvent.closed triggered,
  int _closedCount;

  /// ## Description
  ///
  /// * Fuction for the default Listener, on the LeftApplication event.
  ///
  /// ## Parameters
  ///
  /// * none
  AdLeftApplicationFunction onLeftApplication;

  /// Amount of times the MobileAdEvent.leftApplication triggered
  int _leftApplicationCount;

  /// ## Description
  ///
  /// * Fuction for the default Listener, on the AdFailedToLoad event.
  ///
  /// ## Parameters
  ///
  /// * none
  AdFailedToLoadFunction onAdFailedToLoad;

  /// Amount of times the MobileAdEvent.failedToLoad triggered
  int _failedToLoadCount;

  /// ## Description
  ///
  /// * Fuction for the default Listener, on every event.
  ///
  /// ## Parameters
  ///
  /// * String event
  MobileAdEventTriggeredFunction onAdEvent;

  /// ## Description
  ///
  /// * You `have to` call [EasyAds.initialize], otherwise this class will not work.
  ///
  ///
  /// * The [load] method is called in the constructor.
  ///
  /// ## Example
  ///
  /// {@tool sample}
  /// ```
  /// class MyAdWidget extends StatefulWidget {
  ///   @override
  ///   _MyAdWidgetState createState() => _MyAdWidgetState();
  /// }
  ///
  /// class _MyAdWidgetState extends State<MyAdWidget> {
  ///   EasyInterstitialAd myTestAd;
  ///
  ///   @override
  ///   void initState() {
  ///     super.initState();
  ///     myTestAd = EasyInterstitialAd();
  ///   }
  ///
  ///   @override
  ///   Widget build(BuildContext context) {
  ///     return Scaffold(
  ///       body: Container(
  ///         child: Center(
  ///           child: RaisedButton(onPressed: myTestAd.show),
  ///         ),
  ///       ),
  ///     );
  ///   }
  /// }
  ///
  /// ```
  /// {@end-tool}
  EasyInterstitialAd({
    this.adUnitId,
    this.targetingInfo,
    this.onAdLoaded,
    this.onAdClicked,
    this.onAdOpened,
    this.onAdImpression,
    this.onAdClosed,
    this.onLeftApplication,
    this.onAdFailedToLoad,
    this.onAdEvent,
  }) {
    _initAdListener();
    _initValues();

    _interstitialAd = InterstitialAd(
      adUnitId: adUnitId,
      targetingInfo: targetingInfo,
      listener: _listener,
    );

    load();
  }

  ///returns:
  ///```
  ///AdType.INTERSTITIAL
  ///```
  AdType get adType => AdType.INTERSTITIAL;

  void _initValues() {
    adUnitId = adUnitId ?? EasyInterstitialAd.testAdUnitId;
    targetingInfo = targetingInfo ?? EasyAds.defaultTargetingInfo;

    _loadedCount = 0;
    _openedCount = 0;
    _impressionCount = 0;
    _closedCount = 0;
    _leftApplicationCount = 0;
    _failedToLoadCount = 0;
  }

  void _initAdListener() {
    _listener = (MobileAdEvent event) {
      switch (event) {
        case MobileAdEvent.loaded:
          _loadedCount++;
          if (onAdLoaded != null) onAdLoaded();
          break;

        case MobileAdEvent.clicked:
          _clickedCount++;
          if (onAdClicked != null) onAdClicked();
          break;

        case MobileAdEvent.opened:
          _openedCount++;
          if (onAdOpened != null) onAdOpened();
          break;

        case MobileAdEvent.closed:
          _closedCount++;
          if (onAdClosed != null) onAdClosed();
          break;

        case MobileAdEvent.impression:
          _impressionCount++;
          if (onAdImpression != null) onAdImpression();
          break;

        case MobileAdEvent.leftApplication:
          _leftApplicationCount++;
          if (onLeftApplication != null) onLeftApplication();
          break;

        case MobileAdEvent.failedToLoad:
          _failedToLoadCount++;
          if (onAdFailedToLoad != null) onAdFailedToLoad();
          break;
        default:
          if (onAdEvent != null) onAdEvent(event);
      }
    };
  }

  Future<bool> load() => _interstitialAd.load();

  Future<bool> isLoaded() => _interstitialAd.isLoaded();

  /// ## Description
  ///
  /// * The ad must have been loaded with `load` first.
  ///   If loading hasn't finished the ad will not actually
  ///   appear until the ad has finished loading.
  ///
  ///
  /// * The event specific method will get called when the ad has finished
  ///   loading or fails to do so e.g.:
  ///   ```
  ///   MobileAdEvent.loaded => onAdLoaded()
  ///   ```
  ///
  ///
  /// * `anchorOffset` is the logical pixel offset from the edge
  ///   of the screen (default 0.0). `anchorType` place advert at
  ///   top or bottom of screen (default bottom).
  Future<bool> show({
    double anchorOffset = 0.0,
    double horizontalCenterOffset = 0.0,
    AnchorType anchorType = AnchorType.bottom,
  }) =>
      _interstitialAd.show(
          anchorOffset: anchorOffset,
          horizontalCenterOffset: horizontalCenterOffset,
          anchorType: anchorType);

  /// ## Description
  ///
  /// * Put this in `dispose` or `deactivate`, if you are using
  ///   a Stateful Widget
  ///
  ///
  /// * Free the plugin resources associated with this ad.
  ///
  ///
  /// * Disposing a banner ad that's been shown removes it from the screen.
  ///   Interstitial ads can't be programmatically removed from view.
  Future<bool> dispose() => _interstitialAd.dispose();

  /// Get the InterstitialAd instance from the `firebase_admob` library
  InterstitialAd get interstitialAd => _interstitialAd;

  /// * Amount of times the MobileAdEvent.loaded triggered.
  ///
  ///
  /// * Before `onAdLoaded` is called `loadedCount` gets executed.
  ///
  ///
  /// * This value will not be saved in any form.
  int get loadedCount => _loadedCount;

  /// * Amount of times the MobileAdEvent.clicked triggered.
  ///
  ///
  /// * Before `onAdClicked` is called `clickedCount` gets executed.
  ///
  ///
  /// * This value will not be saved in any form.
  int get clickedCount => _clickedCount;

  /// * Amount of times the MobileAdEvent.opened triggered.
  ///
  ///
  /// * Before `onAdOpened` is called `openedCount` gets executed.
  ///
  ///
  /// * This value will not be saved in any form.
  int get openedCount => _openedCount;

  /// * Amount of times the MobileAdEvent.impression triggered.
  ///
  ///
  /// * Before `onAdImpression` is called `impressionCount` gets executed.
  ///
  ///
  /// * This value will not be saved in any form.
  int get impressionCount => _impressionCount;

  /// * Amount of times the MobileAdEvent.closed triggered.
  ///
  ///
  /// * Before `onAdClosed` is called `closedCount` gets executed.
  ///
  ///
  /// * This value will not be saved in any form.
  int get closedCount => _closedCount;

  /// * Amount of times the MobileAdEvent.leftApplication triggered.
  ///
  ///
  /// * Before `onLeftApplication` is called `leftApplicationCount` gets executed.
  ///
  ///
  /// * This value will not be saved in any form.
  int get leftApplicationCount => _leftApplicationCount;

  /// * Amount of times the MobileAdEvent.failedToLoad triggered.
  ///
  ///
  /// * Before `onAdFailedToLoad` is called `failedToLoadCount` gets executed.
  ///
  ///
  /// * This value will not be saved in any form.
  int get failedToLoadCount => _failedToLoadCount;
}
